==> kmysqladmin-0.5.1.tar.gz: kmysqladmin-0.5.1/kmysqladmin/resource.h <==
/***************************************************************************
                          resource.h  -  description
                             -------------------
    begin                : Sam Sep  2 13:06:53 CEST 2000
    copyright            : (C) 2000 by Rajko Albrecht
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// File-menu entries
#define ID_FILE_NEW_WINDOW          10010
#define ID_FILE_NEW                 10020
#define ID_FILE_OPEN                10030
#define ID_FILE_OPEN_RECENT         10040
#define ID_FILE_CLOSE               10050

#define ID_FILE_SAVE                10060
#define ID_FILE_SAVE_AS             10070

#define ID_FILE_PRINT               10080

#define ID_FILE_QUIT                10090

///////////////////////////////////////////////////////////////////
// Edit-menu entries
#define ID_EDIT_COPY                11010
#define ID_EDIT_CUT                 11020
#define ID_EDIT_PASTE               11030

///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020

///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP_CONTENTS            1002

///////////////////////////////////////////////////////////////////
// General application values
#define ID_STATUS_MSG               1001

#define IDS_STATUS_DEFAULT          "Ready."

#endif // RESOURCE_H

==> kmysqladmin-0.6.2.tar.gz: kmysqladmin-0.6.2/kmysqladmin/resource.h <==
// -*- Mode: C++; -*-
/***************************************************************************
                          resource.h  -  description
                             -------------------
    begin                : Sam Sep  2 13:06:53 CEST 2000
    copyright            : (C) 2000 by Rajko Albrecht
    email                : Rajko.Albrecht@informatik.tu-chemnitz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// File-menu entries
#define ID_FILE_NEW_WINDOW          10010
#define ID_FILE_NEW                 10020
#define ID_FILE_OPEN                10030
#define ID_FILE_OPEN_RECENT         10040
#define ID_FILE_CLOSE               10050

#define ID_FILE_SAVE                10060
#define ID_FILE_SAVE_AS             10070

#define ID_FILE_PRINT               10080

#define ID_FILE_QUIT                10090

///////////////////////////////////////////////////////////////////
// Edit-menu entries
#define ID_EDIT_COPY                11010
#define ID_EDIT_CUT                 11020
#define ID_EDIT_PASTE               11030

///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020

///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP_CONTENTS            1002

///////////////////////////////////////////////////////////////////
// General application values
#define ID_STATUS_MSG               1001

#define IDS_STATUS_DEFAULT          "Ready."

//////////////////////////////////////////////////////////////////
// Special values
#define ID_CONNECT                 13000
#define ID_DISCONNECT              13001
#define ID_RESTORE_LOGIN           13002
#define ID_FLUSH_OUTPUT            13003
#define ID_FILE_OUTPUT             13004

#define ID_DEL_DB                  13005
#define ID_REN_TABLE               13006
#define ID_FLUSH_CACHE             13007
#define ID_DEL_TABLE               13008
#define ID_CLOSE_TABLES            13009
#define ID_NEW_LOG                 13010
#define ID_REFRESH_ACCESS          13011
#define ID_SHUTDOWN                13012
#define ID_SQL_EDIT                13013

#define ID_ACCESS_RIGHTS           13014
#define ID_STATUS                  13015
#define ID_THREADS                 13016
#define ID_NEW_DB                  13017
#define ID_NEW_TABLE               13018
#define ID_MODIFY_TABLE            13019
#define ID_SEARCH_TABLE            13020

#endif // RESOURCE_H
